resource kubernetes_namespace game-servers {
    count = length(var.game_servers.configs) > 0 ? 1 : 0
    metadata {
        name = var.game_servers.namespace
    }
}

resource kubernetes_pod game {
    for_each = var.game_servers.configs

    metadata {
        name = each.key
        namespace = var.game_servers.namespace
        labels = {
            app = each.key
        }
    }
    spec {
        container {
            image = each.value.image
            name  = coalesce(each.value.name, each.key)
            resources {
                limits = {
                    cpu    = each.value.cpu
                    memory = each.value.mem
                }
            }
            port {
                container_port = each.value.port.internal
                protocol       = coalesce(each.value.proto, "TCP")
            }
        }
    }
}

resource kubernetes_service game {
    for_each = var.game_servers.configs
    metadata {
        name = each.key
        namespace = var.game_servers.namespace
        labels = {
            app = each.key
        }
    }
    spec {
        selector = {
            app = each.key
        }
        port {
            target_port        = each.value.port.internal
            port   = each.value.port.expose
        }
        type = "NodePort"
    }
}
